==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/screenshot/translations/screenshot_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Ogólne ustawienia</translation>
    </message>
    <message>
        <source>File format</source>
        <translation>Format pliku</translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation>Wybierz format obrazka, w jakim ma zostać zapisany zrzut.</translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation>Wymuś rozszerzenie .jpg dla formatu JPEG</translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation>Wymusza użycie krótkiego rozszerzenia .jpg dla plików w formacie JPEG. Niektóre komunikatory tego wymagają.</translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation>Jakość obrazka</translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation>-1 to autodetekcja, 0 to najlepsza kompresja, 100 to najlepsza jakość.</translation>
    </message>
    <message>
        <source>Paste [IMAGE] clause automatically</source>
        <translation>Wklejaj polecenie [IMAGE] automatycznie</translation>
    </message>
    <message>
        <source>When enabled, module will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation>Kiedy włączone, moduł automatycznie wklei polecenie [IMAGE] do okna rozmowy, aby było gotowe do wysłania.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation>Ścieżka do katalogu ze zrzutami</translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation>Prefiks nazwy pliku zrzutów ekranu</translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation>Kontroluj rozmiar katalogu</translation>
    </message>
    <message>
        <source>When enabled, module will check for shots directory size and warn you if it gets size specified below.</source>
        <translation>Kiedy włączone, moduł będzie sprawdzał rozmiar katalogu zrzutów i ostrzeże cię, jeśli będzie on większy niż ten podany niżej.</translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation>Maksymalny rozmiar katalogu</translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before module will warn you.</source>
        <translation>Określa, ile kilobajtów mogą zajmować zrzuty w katalogu, zanim moduł cię ostrzeże.</translation>
    </message>
    <message>
        <source> kB</source>
        <translation> kB</translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation>Limit rozmiaru katalogu ze zrzutami</translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation>Rozmiar obrazka większy niż maksymalny rozmiar dla tej rozmowy.</translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation>Nie można utworzyć katalogu %1 dla zapisywania zrzutów ekranu!</translation>
    </message>
    <message>
        <source>Can&apos;t write file %1.
Access denied or other problem!</source>
        <translation>Nie można pisać do pliku %1.
Brak dostępu lub inny problem!</translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation>Zrzut ekranu %1 ma zerowy rozmiar!
Powinien być większy.</translation>
    </message>
</context>
<context>
    <name>ScreenshotActions</name>
    <message>
        <source>ScreenShot</source>
        <translation>ScreenShot</translation>
    </message>
    <message>
        <source>Simple shot</source>
        <translation>Zwykły zrzut</translation>
    </message>
    <message>
        <source>With chat window hidden</source>
        <translation>Z ukrytym oknem rozmowy</translation>
    </message>
    <message>
        <source>Window shot</source>
        <translation>Zrzut okna</translation>
    </message>
</context>
<context>
    <name>ScreenshotNotification</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation>Limit rozmiaru zrzutów</translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation>Limit rozmiaru zrzutów został przekroczony: %1 KB</translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag icon to some window</source>
        <translation>Przeciągnij kursor nad jakieś okno</translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation>0 KiB</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Przytnij</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
</TS>

==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/screenshot/translations/screenshot_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Ogólne ustawienia</translation>
    </message>
    <message>
        <source>File format</source>
        <translation>Format pliku</translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation>Wybierz format obrazka, w jakim ma zostać zapisany zrzut.</translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation>Wymuś rozszerzenie .jpg dla formatu JPEG</translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation>Wymusza użycie krótkiego rozszerzenia .jpg dla plików w formacie JPEG. Niektóre komunikatory tego wymagają.</translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation>Jakość obrazka</translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation>-1 to autodetekcja, 0 to najlepsza kompresja, 100 to najlepsza jakość.</translation>
    </message>
    <message>
        <source>Paste [IMAGE] clause automatically</source>
        <translation>Wklejaj polecenie [IMAGE] automatycznie</translation>
    </message>
    <message>
        <source>When enabled, module will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation>Kiedy włączone, moduł automatycznie wklei polecenie [IMAGE] do okna rozmowy, aby było gotowe do wysłania.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation>Ścieżka do katalogu ze zrzutami</translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation>Prefiks nazwy pliku zrzutów ekranu</translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation>Kontroluj rozmiar katalogu</translation>
    </message>
    <message>
        <source>When enabled, module will check for shots directory size and warn you if it gets size specified below.</source>
        <translation>Kiedy włączone, moduł będzie sprawdzał rozmiar katalogu zrzutów i ostrzeże cię, jeśli będzie on większy niż ten podany niżej.</translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation>Maksymalny rozmiar katalogu</translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before module will warn you.</source>
        <translation>Określa, ile kilobajtów mogą zajmować zrzuty w katalogu, zanim moduł cię ostrzeże.</translation>
    </message>
    <message>
        <source> kB</source>
        <translation> kB</translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation>Limit rozmiaru katalogu ze zrzutami</translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation>Rozmiar obrazka większy niż maksymalny rozmiar dla tej rozmowy.</translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation>Nie można utworzyć katalogu %1 dla zapisywania zrzutów ekranu!</translation>
    </message>
    <message>
        <source>Can&apos;t write file %1.
Access denied or other problem!</source>
        <translation>Nie można pisać do pliku %1.
Brak dostępu lub inny problem!</translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation>Zrzut ekranu %1 ma zerowy rozmiar!
Powinien być większy.</translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>ScreenShot</source>
        <translation>ScreenShot</translation>
    </message>
    <message>
        <source>Simple shot</source>
        <translation>Zwykły zrzut</translation>
    </message>
    <message>
        <source>With chat window hidden</source>
        <translation>Z ukrytym oknem rozmowy</translation>
    </message>
    <message>
        <source>Window shot</source>
        <translation>Zrzut okna</translation>
    </message>
</context>
<context>
    <name>ScreenshotNotification</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation>Limit rozmiaru zrzutów</translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation>Limit rozmiaru zrzutów został przekroczony: %1 KB</translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag icon to some window</source>
        <translation>Przeciągnij kursor nad jakieś okno</translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation>0 KiB</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Przytnij</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
</TS>
